=====
Djecrety
=====

.. image:: https://travis-ci.org/mrouhi13/djecrety.svg?branch=master
    :target: https://travis-ci.org/mrouhi13/djecrety

.. image:: https://readthedocs.org/projects/djecrety/badge/?version=latest
  :target: https://djecrety.readthedocs.io/en/latest/?badge=latest
  :alt: Documentation Status

.. image:: https://codecov.io/gh/mrouhi13/djecrety/branch/master/graph/badge.svg
  :target: https://codecov.io/gh/mrouhi13/djecrety

Djecrety is an implementation of the Django package from a `Web tool <https://djecrety.ir/>`_ with the same name. This package provides a command to generate a new secret key for your project and save it to ``settings.py`` file.

For more details `http://djecrety.readthedocs.io <http://djecrety.readthedocs.io>`_

Requirements
============
To be able to run **Djecrety** you have to meet following requirements:

- Python (3.5, 3.6)
- Django (2.0, 2.1, 2.2)

Bear in mind that for Django-2.x you will need at least Python 3.5

Installation
============
Simply install using ``pip``:

.. code-block:: bash

    $ pip install djecrety

Documentation
=============
Documentation is available to study at
`http://djecrety.readthedocs.io <http://djecrety.readthedocs.io>`_
and in ``docs`` directory.
